@@ -30,14 +30,14 @@ from typing import (
     Any,
     Final,
     Protocol,
+    TypeAlias,
+    TypeGuard,
     TypeVar,
     Union,
     cast,
     runtime_checkable,
 )
 
-from typing_extensions import TypeAlias, TypeGuard
-
 from streamlit import config, errors, logger, string_util
 from streamlit.type_util import (
     CustomDict,
@@ -165,12 +165,12 @@ class DataframeInterchangeCompatible(Protocol):
     def __dataframe__(self, allow_copy: bool) -> Any: ...
 
 
-OptionSequence: TypeAlias = Union[
-    Iterable[V_co],
-    DataFrameGenericAlias[V_co],
-    PandasCompatible,
-    DataframeInterchangeCompatible,
-]
+OptionSequence: TypeAlias = (
+    Iterable[V_co]
+    | DataFrameGenericAlias[V_co]
+    | PandasCompatible
+    | DataframeInterchangeCompatible
+)
 
 # Various data types supported by our dataframe processing
 # used for commands like `st.dataframe`, `st.table`, `st.map`,
@@ -528,6 +528,13 @@ def _dict_to_pandas_df(data: dict[Any, Any]) -> DataFrame:
     return _fix_column_naming(pd.DataFrame.from_dict(data, orient="index"))
 
 
+def has_range_index(df: DataFrame) -> bool:
+    """True if the dataframe has a range index."""
+    from pandas import RangeIndex
+
+    return isinstance(df.index, RangeIndex)
+
+
 def convert_anything_to_pandas_df(
     data: Any,
     max_unevaluated_rows: int = _MAX_UNEVALUATED_DF_ROWS,
