@@ -15,9 +15,7 @@
 from __future__ import annotations
 
 from collections.abc import Sequence
-from typing import TYPE_CHECKING, Literal, Union, cast
-
-from typing_extensions import TypeAlias
+from typing import TYPE_CHECKING, Literal, TypeAlias, cast
 
 from streamlit.delta_generator_singletons import get_dg_singleton_instance
 from streamlit.elements.lib.layout_utils import (
@@ -54,7 +52,7 @@ if TYPE_CHECKING:
     from streamlit.elements.lib.mutable_status_container import StatusContainer
     from streamlit.runtime.state import WidgetCallback
 
-SpecType: TypeAlias = Union[int, Sequence[Union[int, float]]]
+SpecType: TypeAlias = int | Sequence[int | float]
 
 
 class LayoutsMixin:
@@ -385,13 +383,15 @@ class LayoutsMixin:
             ``False`` (default), no border is shown. If this is ``True``, a
             border is shown around each column.
 
-        width : int or "stretch"
-            The desired width of the columns expressed in pixels. If this is
-            ``"stretch"`` (default), Streamlit sets the width of the columns to
-            match the width of the parent container. Otherwise, this must be an
-            integer. If the specified width is greater than the width of the
-            parent container, Streamlit sets the width of the columns to match
-            the width of the parent container.
+        width : "stretch" or int
+            The width of the column group. This can be one of the following:
+
+            - ``"stretch"`` (default): The width of the column group matches the
+              width of the parent container.
+            - An integer specifying the width in pixels: The column group has a
+              fixed width. If the specified width is greater than the width of
+              the parent container, the width of the column group matches the
+              width of the parent container.
 
         Returns
         -------
@@ -862,6 +862,7 @@ class LayoutsMixin:
         self,
         label: str,
         *,
+        type: Literal["primary", "secondary", "tertiary"] = "secondary",
         help: str | None = None,
         icon: str | None = None,
         disabled: bool = False,
@@ -912,6 +913,17 @@ class LayoutsMixin:
             including the Markdown directives described in the ``body``
             parameter of ``st.markdown``.
 
+        type : "primary", "secondary", or "tertiary"
+            An optional string that specifies the button type. This can be one
+            of the following:
+
+            - ``"primary"``: The button's background is the app's primary color
+              for additional emphasis.
+            - ``"secondary"`` (default): The button's background coordinates
+              with the app's background color for normal emphasis.
+            - ``"tertiary"``: The button is plain text without a border or
+              background for subtlety.
+
         icon : str
             An optional emoji or icon to display next to the button label. If ``icon``
             is ``None`` (default), no icon is displayed. If ``icon`` is a
@@ -1009,9 +1021,17 @@ class LayoutsMixin:
         if use_container_width is not None:
             width = "stretch" if use_container_width else "content"
 
+        # Checks whether the entered button type is one of the allowed options
+        if type not in ["primary", "secondary", "tertiary"]:
+            raise StreamlitAPIException(
+                'The type argument to st.popover must be "primary", "secondary", or "tertiary". '
+                f'\nThe argument passed was "{type}".'
+            )
+
         popover_proto = BlockProto.Popover()
         popover_proto.label = label
         popover_proto.disabled = disabled
+        popover_proto.type = type
         if help:
             popover_proto.help = str(help)
         if icon is not None:
