@@ -14,14 +14,13 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Literal, Union, cast
-
-from typing_extensions import TypeAlias
+from typing import Literal, TypeAlias, cast
 
 from streamlit.errors import (
     StreamlitInvalidColumnGapError,
     StreamlitInvalidHeightError,
     StreamlitInvalidHorizontalAlignmentError,
+    StreamlitInvalidSizeError,
     StreamlitInvalidVerticalAlignmentError,
     StreamlitInvalidWidthError,
 )
@@ -30,19 +29,29 @@ from streamlit.proto.GapSize_pb2 import GapSize
 from streamlit.proto.HeightConfig_pb2 import HeightConfig
 from streamlit.proto.WidthConfig_pb2 import WidthConfig
 
-WidthWithoutContent: TypeAlias = Union[int, Literal["stretch"]]
-Width: TypeAlias = Union[int, Literal["stretch", "content"]]
-HeightWithoutContent: TypeAlias = Union[int, Literal["stretch"]]
-Height: TypeAlias = Union[int, Literal["stretch", "content"]]
+WidthWithoutContent: TypeAlias = int | Literal["stretch"]
+Width: TypeAlias = int | Literal["stretch", "content"]
+HeightWithoutContent: TypeAlias = int | Literal["stretch"]
+Height: TypeAlias = int | Literal["stretch", "content"]
+SpaceSize: TypeAlias = int | Literal["stretch", "small", "medium", "large"]
 Gap: TypeAlias = Literal["small", "medium", "large"]
 HorizontalAlignment: TypeAlias = Literal["left", "center", "right", "distribute"]
 VerticalAlignment: TypeAlias = Literal["top", "center", "bottom", "distribute"]
 
+# Mapping of size literals to rem values for st.space
+# If changing these, also check streamlit/frontend/lib/src/theme/primitives/sizes.ts
+# to ensure sizes are kept in sync.
+SIZE_TO_REM_MAPPING = {
+    "small": 0.75,  # Height of widget label minus gap
+    "medium": 2.5,  # Height of button/input field
+    "large": 4.25,  # Height of large widget without label
+}
+
 
 @dataclass
 class LayoutConfig:
-    width: Width | None = None
-    height: Height | None = None
+    width: Width | SpaceSize | None = None
+    height: Height | SpaceSize | None = None
 
 
 def validate_width(width: Width, allow_content: bool = False) -> None:
@@ -117,9 +126,35 @@ def validate_height(
         raise StreamlitInvalidHeightError(height, allow_content)
 
 
-def get_width_config(width: Width) -> WidthConfig:
+def validate_space_size(size: SpaceSize) -> None:
+    """Validate the size parameter for st.space.
+
+    Parameters
+    ----------
+    size : Any
+        The size value to validate.
+
+    Raises
+    ------
+    StreamlitInvalidSizeError
+        If the size value is invalid.
+    """
+    if not isinstance(size, (int, str)):
+        raise StreamlitInvalidSizeError(size)
+
+    if isinstance(size, str):
+        valid_strings = ["stretch", "small", "medium", "large"]
+        if size not in valid_strings:
+            raise StreamlitInvalidSizeError(size)
+    elif isinstance(size, int) and size <= 0:
+        raise StreamlitInvalidSizeError(size)
+
+
+def get_width_config(width: Width | SpaceSize) -> WidthConfig:
     width_config = WidthConfig()
-    if isinstance(width, (int, float)):
+    if isinstance(width, str) and width in SIZE_TO_REM_MAPPING:
+        width_config.rem_width = SIZE_TO_REM_MAPPING[width]
+    elif isinstance(width, (int, float)):
         width_config.pixel_width = int(width)
     elif width == "content":
         width_config.use_content = True
@@ -128,9 +163,11 @@ def get_width_config(width: Width) -> WidthConfig:
     return width_config
 
 
-def get_height_config(height: Height) -> HeightConfig:
+def get_height_config(height: Height | SpaceSize) -> HeightConfig:
     height_config = HeightConfig()
-    if isinstance(height, (int, float)):
+    if isinstance(height, str) and height in SIZE_TO_REM_MAPPING:
+        height_config.rem_height = SIZE_TO_REM_MAPPING[height]
+    elif isinstance(height, (int, float)):
         height_config.pixel_height = int(height)
     elif height == "content":
         height_config.use_content = True
