@@ -36,3 +36,11 @@ st.write(
     - Explore a [New York City rideshare dataset](https://github.com/streamlit/demo-uber-nyc-pickups)
     """
 )
+
+# Preload Python modules that take a while to compile in a new venv.
+# Otherwise, when users switch to another page, it seems that Streamlit
+# is slow, when in reality this is just an artifact of loading/compiling
+# large modules from zero.
+with st.spinner("Preloading Python modules for other pages..."):
+    import numpy  # noqa: ICN001 F401
+    import pandas  # noqa: ICN001 F401
