@@ -15,9 +15,9 @@
 from __future__ import annotations
 
 import re
-from typing import TYPE_CHECKING, TextIO, TypedDict
+from typing import TYPE_CHECKING, TextIO, TypeAlias, TypedDict
 
-from typing_extensions import NotRequired, TypeAlias
+from typing_extensions import NotRequired
 
 from streamlit.string_util import extract_leading_emoji
 
